require 'httparty'

module DmLiveResources
  class DMSheet
    attr_reader :api_key, :name, :file, :description, :id, :content_type, :auth, :resource_hash
    include HTTParty

    def initialize(args = {})
      @api_key = args[:dm_api_key]
      @file = args[:file]
      @description = args[:description]
      @name = args[:name] ||= "#{description}.xlsx"
      @id = args[:dm_id] ||= find_resource_id
    end

    def auth
      @auth = { username: api_key, password: "p" }
    end

    def content_type
      @content_type = "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"
    end

    def resource_hash
      @resource_hash = { "description" => description,"file" => { "file_name" => name,
            "file_data" => file, "content_type" => content_type }}
      @resource_hash
    end

    def request_options
      @request_options = { basic_auth: auth, body: {"resource" => resource_hash }}
      @request_options
    end

    def id
      @id = find_resource_id
      @id
    end

    def list_resources
      options = { basic_auth: auth }
      response = self.class.get('https://www.devicemagic.com/api/resources.json', options)
      resources = response['resources']
      return resources
    end

    def find_resource_id
      resources = list_resources
      resources.each do |resource|
        if resource['original_filename'] == name && resource['description'] == description
          id = resource['id']
          return id
        end
      end
    end

    def add_resource
      self.class.post('https://www.devicemagic.com/api/resources.json', request_options)
    end

    def update_resource
      self.class.put("https://www.devicemagic.com/api/resources/#{id}.json", request_options)
    end
  end
end
