require 'base64'
require 'httparty'

module DmLiveResources
	class GSheet
		attr_reader :api_key, :identifier, :title, :sheets, :content_type, :exported_file, :content
		include HTTParty

		def initialize(args = {})
			@api_key = args[:gs_api_key]
			@identifier = args[:gs_identifier]
			@title = args[:gs_title] ||= get_title
			@sheets = args[:gs_sheets] ||= "Sheet1"
	  	end

		def content_type
			@content_type = "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"
		end

		def content
			options = { :query => {:key => api_key} }
			request = self.class.get("https://sheets.googleapis.com/v4/spreadsheets/#{identifier}/values:batchGet?#{ranges}", options)
			@content = request.to_s
		end

		def get_title
			params = { mimeType: content_type, key: api_key }
			request = self.class.get("https://www.googleapis.com/drive/v3/files/#{identifier}", query: params)
			@title = request["name"]
		end

		def ranges
			split_sheets = sheets.split(", ")
			range = split_sheets.map {|sheet| "ranges=#{sheet}"}
			range = range.join("&")
			return range
		end

		def exported_file
			params = { mimeType: content_type, key: api_key }
			request = self.class.get("https://www.googleapis.com/drive/v3/files/#{identifier}/export", query: params)
			contents = request.body
			@exported_file = Base64.encode64(contents)
		end
	end
end
