require_relative 'g_sheet.rb'
require_relative 'dm_sheet.rb'
require_relative 'resource.rb'

module DmLiveResources
  class ResourceManager
    attr_reader :gsheet_api_key, :gsheet_identifier, :gsheet_title, :gsheet_content,
    :gsheet_sheets, :dmagic_api_key, :dmagic_id, :table_name
    @@db = Resource.db

    def initialize(args = {})
      @gsheet_identifier = args[:gs_identifier]
      @gsheet_title = args[:gs_title]
      @gsheet_content = args[:gs_content]
      @gsheet_sheets = args[:gs_sheets]
      @gsheet_api_key = args[:gs_api_key]
      @dmagic_api_key = args[:dm_api_key]
      @dmagic_id = args[:dm_id]
    end

    def table_name
      gsheet_title
    end

    def create_new_table
      @@db.execute %Q{
       CREATE TABLE IF NOT EXISTS #{table_name} (
       Id INTEGER PRIMARY KEY,
       GSheetApiKey,
       GSheetIdentifier,
       GSheetTitle,
       GSheetContent,
       GSheetSheets,
       DMagicApiKey,
       DMagicId,
       DateAdded datetime default current_timestamp)
       }
     @@db.execute(Resource.insert_query(table_name), gsheet_api_key, gsheet_identifier, gsheet_title, gsheet_content, gsheet_sheets, dmagic_api_key, dmagic_id)
    end

    def self.check_tables(tables)
      @@db.results_as_hash = true
      tables.each do |table|
        # Retrieve the last row added to the table
        row = @@db.get_first_row("SELECT * FROM '#{table}' ORDER BY DateAdded DESC LIMIT 1")
        resource_data = Resource.data_as_hash(row['GSheetApiKey'], row['GSheetIdentifier'], row['GSheetSheets'], row['GSheetTitle'], row['DMagicApiKey'], row['DMagicId'])
        sheet = GSheet.new(resource_data)
        if Resource.update_required?(row, sheet)
          resource_data = Resource.add_gsheet_data(resource_data, sheet.exported_file, sheet.title)
          dm = DMSheet.new(resource_data)
          dm.update_resource
          @@db.execute(Resource.insert_query(table), sheet.api_key, sheet.identifier, sheet.title, sheet.content, sheet.sheets, dm.api_key, dm.id)
        end
      end
    end

    def self.update_db_tables
      tables = Resource.return_tables
      self.check_tables(tables)
    end
  end
end
